.. _utilities:

Utility & Helper Methods
========================

Sections

* `Get Information`_
* `Verification`_
* `Index Pruning`_
* `Other`_


Get Information
---------------

get_alias
+++++++++
.. automethod:: curator.api.get_alias

get_indices
+++++++++++
.. automethod:: curator.api.get_indices

get_repository
++++++++++++++
.. automethod:: curator.api.get_repository

get_segmentcount
++++++++++++++++
.. automethod:: curator.api.get_segmentcount

get_snapshot
++++++++++++
.. automethod:: curator.api.get_snapshot

get_snapshots
+++++++++++++
.. automethod:: curator.api.get_snapshots

get_version
+++++++++++
.. automethod:: curator.api.get_version


Verification
------------

check_csv
+++++++++
.. automethod:: curator.api.check_csv

ensure_list
+++++++++++
.. automethod:: curator.api.ensure_list

index_closed
++++++++++++
.. automethod:: curator.api.index_closed

optimized
+++++++++
.. automethod:: curator.api.optimized

is_master_node
++++++++++++++
.. automethod:: curator.api.is_master_node

to_csv
++++++
.. automethod:: curator.api.to_csv


Index Pruning
-------------

prune_allocated
+++++++++++++++
.. automethod:: curator.api.prune_allocated

prune_closed
++++++++++++
.. automethod:: curator.api.prune_closed

prune_kibana
++++++++++++
.. automethod:: curator.api.prune_kibana


Other
-----

create_snapshot_body
++++++++++++++++++++
.. automethod:: curator.api.create_snapshot_body

chunk_index_list
++++++++++++++++
.. automethod:: curator.api.chunk_index_list
